@@ -1,3 +1,9 @@
 from ._version import __version__
 from .visualize_activations import visualize_activations
-from .visualize_action_volume_boxes import VisualizeBoxes
\ No newline at end of file
+from .visualize_action_volume_boxes import VisualizeBoxes
+
+__all__ = (
+    
+    "visualize_activations",
+    "VisualizeBoxes",
+)
\ No newline at end of file
